example_ballots: Example ballot-level data

example_ballotsR Documentation

Example ballot-level data

Description

A small simulated dataset used in examples and tests. The dataset contains 100 simulated observations from five simulated precincts in Lee county, with pre-election and U.S. Senate vote categories.

Usage

data(example_ballots)

Format

A data frame with 100 rows and 4 variables:

COUNTY

County name.

PRECINCT

Precinct identifier.

PRE

Pre-election vote category.

USS

U.S. Senate vote category; may contain missing values.

Simulated data generated for examples.


eiballots documentation built on Sept. 26, 2026, 5:06 p.m.