list_elections: List available races

View source: R/data_access.R

list_electionsR Documentation

List available races

Description

Returns a summary data.frame of the races available in the dataset, optionally filtered by type or level.

Usage

list_elections(type = NULL, level = NULL)

Arguments

type

Optional. Filter by race type: "single_member", "multi_member", or "referendum".

level

Optional. Filter by scope: "federal", "state", "county", "district", or "local".

Value

A data.frame with columns code, office, type, level, and counties.

See Also

election_catalog, list_counties()

Examples

list_elections()
list_elections(level = "federal")
list_elections(type = "referendum")


eiballots documentation built on Sept. 26, 2026, 5:06 p.m.