to_lphom: Convert an ei_summary to lphom list format

View source: R/ei_summary.R

to_lphomR Documentation

Convert an ei_summary to lphom list format

Description

Converts the margins element to a named list of data.frames (one per race). This is the default format of ei_summary() and the input format expected by lphom and related ecological inference functions.

Usage

to_lphom(x)

Arguments

x

An "ei_summary" object.

Value

An "ei_summary" object with margins as a named list of data.frames and meta$format == "lphom".

See Also

to_eipack(), ei_summary()


eiballots documentation built on Sept. 26, 2026, 5:06 p.m.