| county_catalog | R Documentation |
A named list mapping each county data file to the race codes it contains. Used internally to determine which county files must be loaded for a given set of races.
county_catalog
A named list. Each element is named by the county code (matching
the .RData filename without extension) and contains a character vector
of the race codes present in that county's file.
The county code is used to construct the filename: county "Lee" maps to
Lee.RData. This list is consulted by get_election_data() and
ei_summary() to determine which files to load.
election_catalog, list_counties(), get_county_data()
# Races available in Lee county
county_catalog[["Lee"]]
# All counties in the dataset
names(county_catalog)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.