| example_ballots | R Documentation |
A small simulated dataset used in examples and tests. The dataset contains 100 simulated observations from five simulated precincts in Lee county, with pre-election and U.S. Senate vote categories.
data(example_ballots)
A data frame with 100 rows and 4 variables:
County name.
Precinct identifier.
Pre-election vote category.
U.S. Senate vote category; may contain missing values.
Simulated data generated for examples.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.