| summary.ei_summary | R Documentation |
Prints aggregate vote totals and percentages for each race, and (when there are exactly two races) the full joint contingency table.
## S3 method for class 'ei_summary'
summary(object, ...)
object |
An |
... |
Ignored. |
The input object object, returned invisibly. Called for its
side effect of printing aggregate vote totals and the joint
contingency table (when two races are present) to the console.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.